@@ -50,10 +50,10 @@ ArchiveMailInfo &ArchiveMailInfo::operator=(const ArchiveMailInfo &old)
     return *this;
 }
 
-QString normalizeFolderName(const QString &folderName)
+static QString normalizeFolderName(const QString &folderName)
 {
     QString adaptFolderName(folderName);
-    adaptFolderName.replace(QLatin1Char('/'), QLatin1Char('_'));
+    adaptFolderName.replace(u'/', u'_');
     return adaptFolderName;
 }
 
@@ -98,8 +98,8 @@ QUrl ArchiveMailInfo::realUrl(const QString &folderName, bool &dirExist) const
     const char *extensions[numExtensions] = {".zip", ".tar", ".tar.bz2", ".tar.gz"};
     const QString dirPath = dirArchive(dirExist);
 
-    const QString path = dirPath + QLatin1Char('/') + i18nc("Start of the filename for a mail archive file", "Archive") + QLatin1Char('_')
-        + normalizeFolderName(folderName) + QLatin1Char('_') + QDate::currentDate().toString(Qt::ISODate) + QString::fromLatin1(extensions[mArchiveType]);
+    const QString path = dirPath + u'/' + i18nc("Start of the filename for a mail archive file", "Archive") + u'_' + normalizeFolderName(folderName) + u'_'
+        + QDate::currentDate().toString(Qt::ISODate) + QString::fromLatin1(extensions[mArchiveType]);
     const QUrl real(QUrl::fromLocalFile(path));
     return real;
 }
@@ -114,8 +114,8 @@ QStringList ArchiveMailInfo::listOfArchive(const QString &folderName, bool &dirE
     QDir dir(dirPath);
 
     QStringList nameFilters;
-    nameFilters << i18nc("Start of the filename for a mail archive file", "Archive") + QLatin1Char('_') + normalizeFolderName(folderName) + QLatin1Char('_')
-            + "*"_L1 + QString::fromLatin1(extensions[mArchiveType]);
+    nameFilters << i18nc("Start of the filename for a mail archive file", "Archive") + u'_' + normalizeFolderName(folderName) + u'_' + "*"_L1
+            + QString::fromLatin1(extensions[mArchiveType]);
     const QStringList lst = dir.entryList(nameFilters, QDir::Files | QDir::NoDotAndDotDot, QDir::Time | QDir::Reversed);
     return lst;
 }
