@@ -6,7 +6,7 @@
 
 #pragma once
 
-#include <Akonadi/AgentBase>
+#include <Akonadi/AgentWidgetBase>
 
 #include <Akonadi/Collection>
 #include <Akonadi/Item>
@@ -24,7 +24,7 @@ namespace Akonadi
 class Monitor;
 }
 
-class MailFilterAgent : public Akonadi::AgentBase, public Akonadi::AgentBase::ObserverV3
+class MailFilterAgent : public Akonadi::AgentWidgetBase, public Akonadi::AgentBase::ObserverV3
 {
     Q_OBJECT
 
@@ -59,7 +59,7 @@ private:
     void mailCollectionRemoved(const Akonadi::Collection &collection);
     void emitProgress(int percent = 0);
     void emitProgressMessage(const QString &message);
-    void itemsReceiviedForFiltering(const Akonadi::Item::List &items);
+    void itemsReceivedForFiltering(const Akonadi::Item::List &items);
     void clearMessage();
     void slotInstanceRemoved(const Akonadi::AgentInstance &instance);
     void slotItemChanged(const Akonadi::Item &item);
