@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,7 +24,8 @@ RefreshSettingsAssistant::RefreshSettingsAssistant(QWidget *parent)
     resize(640, 480);
     Akonadi::ControlGui::widgetNeedsAkonadi(this);
     initializePages();
-    auto helpMenu = new KHelpMenu(this, KAboutData::applicationData(), true);
+    auto helpMenu = new KHelpMenu(this, KAboutData::applicationData());
+    helpMenu->setShowWhatsThis(true);
     // Initialize menu
     QMenu *menu = helpMenu->menu();
     helpMenu->action(KHelpMenu::menuAboutApp)->setIcon(QIcon::fromTheme(QStringLiteral("kmail")));
