@@ -1,6 +1,6 @@
 /*
  * This file is part of KMail.
- * SPDX-FileCopyrightText: 2011-2024 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2025 Laurent Montel <montel@kde.org>
  *
  * SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
  *
@@ -92,7 +92,7 @@ class Job;
 namespace MessageComposer
 {
 class ComposerLineEdit;
-class Composer;
+class ComposerJob;
 class StatusBarLabelToggledState;
 class RecipientLineNG;
 }
@@ -128,7 +128,7 @@ private: // mailserviceimpl, kmkernel, kmcommands, callback, kmmainwidget
     explicit KMComposerWin(const KMime::Message::Ptr &msg,
                            bool lastSignState,
                            bool lastEncryptState,
-                           TemplateContext context = NoTemplate,
+                           TemplateContext context = TemplateContext::NoTemplate,
                            uint identity = 0,
                            const QString &textSelection = QString(),
                            const QString &customTemplate = QString());
@@ -144,7 +144,7 @@ public:
     static Composer *create(const KMime::Message::Ptr &msg,
                             bool lastSignState,
                             bool lastEncryptState,
-                            TemplateContext context = NoTemplate,
+                            TemplateContext context = TemplateContext::NoTemplate,
                             uint identity = 0,
                             const QString &textSelection = QString(),
                             const QString &customTemplate = QString());
@@ -545,7 +545,7 @@ private:
      *
      * The caller takes ownership of the composer.
      */
-    [[nodiscard]] MessageComposer::Composer *createSimpleComposer();
+    [[nodiscard]] MessageComposer::ComposerJob *createSimpleComposer();
 
     [[nodiscard]] bool canSignEncryptAttachments() const;
 
@@ -553,7 +553,7 @@ private:
     [[nodiscard]] int calcColumnWidth(int which, long allShowing, int width) const;
 
 private:
-    enum CryptoKeyState {
+    enum class CryptoKeyState : int8_t {
         NoState = 0,
         InProgress,
         KeyOk,
@@ -629,7 +629,7 @@ private:
     QFont mBodyFont;
     QFont mFixedFont;
     uint mId = 0;
-    const TemplateContext mContext = NoTemplate;
+    const TemplateContext mContext = TemplateContext::NoTemplate;
 
     KRecentFilesAction *mRecentAction = nullptr;
 
@@ -668,9 +668,9 @@ private:
     QSplitter *mSplitter = nullptr;
     QSplitter *mSnippetSplitter = nullptr;
 
-    MessageComposer::Composer *mDummyComposer = nullptr;
+    MessageComposer::ComposerJob *mDummyComposer = nullptr;
     // used for auto saving, printing, etc. Not for sending, which happens in ComposerViewBase
-    QList<MessageComposer::Composer *> mMiscComposers;
+    QList<MessageComposer::ComposerJob *> mMiscComposers;
 
     int mLabelWidth = 0;
 
