@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "composenewmessagejob.h"
 #include "kmkernel.h"
-#include <MessageComposer/Composer>
+#include <MessageComposer/ComposerJob>
 
 #include <KMime/Message>
 #include <MessageComposer/MessageHelper>
@@ -67,7 +67,7 @@ void ComposeNewMessageJob::start()
 
 void ComposeNewMessageJob::slotOpenComposer(bool forceCursorPosition)
 {
-    KMail::Composer *win = KMail::makeComposer(mMsg, false, false, KMail::Composer::New, mIdentity);
+    KMail::Composer *win = KMail::makeComposer(mMsg, false, false, KMail::Composer::TemplateContext::New, mIdentity);
     win->setCollectionForNewMessage(mCurrentCollection);
 
     if (forceCursorPosition) {
