@@ -14,7 +14,7 @@
 // widgets like a toolbar.
 
 #include "kmreadermainwin.h"
-
+#include "config-kmail.h"
 #include "historyclosedreader/historyclosedreadermanager.h"
 #include "job/composenewmessagejob.h"
 #include "kmmainwidget.h"
@@ -639,7 +639,7 @@ void KMReaderMainWin::slotMessagePopup(const Akonadi::Item &aMsg, const WebEngin
         job->setProperty("imageUrl", imageUrl);
         job->setProperty("url", aUrl);
         job->setProperty("webhitresult", QVariant::fromValue(result));
-        connect(job, &Akonadi::ItemCopyJob::result, this, &KMReaderMainWin::slotContactSearchJobForMessagePopupDone);
+        connect(job, &Akonadi::ContactSearchJob::result, this, &KMReaderMainWin::slotContactSearchJobForMessagePopupDone);
     } else {
         showMessagePopup(mMsg, aUrl, imageUrl, aPoint, false, false, result);
     }
@@ -747,7 +747,7 @@ void KMReaderMainWin::showMessagePopup(const Akonadi::Item &msg,
         mMsgActions->addWebShortcutsMenu(menu, selectedText);
         menu->addSeparator();
         menu->addActions(mReaderWin->viewerPluginActionList(MessageViewer::ViewerPluginInterface::NeedSelection));
-#ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_TEXT_TO_SPEECH_SUPPORT
         menu->addSeparator();
         menu->addAction(mReaderWin->speakTextAction());
 #endif
@@ -766,7 +766,7 @@ void KMReaderMainWin::showMessagePopup(const Akonadi::Item &msg,
                 if (!(CommonKernel->folderIsSentMailFolder(col) || CommonKernel->folderIsDrafts(col) || CommonKernel->folderIsTemplates(col))) {
                     replyForwardMenu = true;
                 }
-            } else if (messageHasPayload) {
+            } else {
                 replyForwardMenu = true;
             }
 
